-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- --
-- Script:  Glider_Wind
-- Version: 1.0
-- Build:   2015-02-16
-- By:      oe3gsu@x-plane.at
-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- --
-- Description:
-- 
-- This script shows the actual wind-speed and direction relative to your plane.
-- you can change the position of the display-center measured from the top right corner of your screen
--   please change only the numbers after "window_x =" and "window_y =" (default: 40) 
-- you can chance if you want to see the display only with gliders ("GW_show_ever = false") or
--   to see it with every plane ("GW_show_ever = true").
-- you can change the brightness of the display with the HUD-Brightness (if your plane has one)
-- if the display is hidden, the script does nothing (no influence on fps)
-- 
-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- --

-- USER editable values -------------------------------------------------------------------------------
--                                                                                                   --
local window_x = 40             -- Display position from right edge of window
local window_y = 40             -- Display position from top edge of window
local GW_show_ever = false      -- if true, show it with every plane, false: only for gliders
--                                                                                                   --
---------- DONT edit anything below this line !!! -----------------------------------------------------

-- STARTUP --------------------------------------------------------------------------

require("graphics")

DataRef("GW_xp_WDir", "sim/cockpit2/gauges/indicators/wind_heading_deg_mag", "readonly")
DataRef("GW_xp_WSpd", "sim/cockpit2/gauges/indicators/wind_speed_kts", "readonly")
DataRef("GW_xp_ADir", "sim/flightmodel/position/mag_psi", "readonly")
DataRef("GW_xp_hud_brht", "sim/cockpit/electrical/HUD_brightness", "readonly")

local i = 0

function GW_main() -------------------------------------------------------- MAIN
  
  if string.match(AIRCRAFT_PATH, "Gliders") or GW_show_ever == true then 
    XPLMSetGraphicsState(0,0,0,1,1,0,0)
    
    graphics.set_color(0.5, 0.5, 0.5, GW_xp_hud_brht)
    graphics.draw_filled_circle(SCREEN_WIDTH - window_x, SCREEN_HIGHT - window_y, 40)
    
    graphics.set_color(0.3, 1.0, 0.0, GW_xp_hud_brht)
    graphics.draw_circle(SCREEN_WIDTH - window_x, SCREEN_HIGHT - window_y, 30, 2)
    graphics.draw_circle(SCREEN_WIDTH - window_x, SCREEN_HIGHT - window_y, 40, 2)
    
    graphics.set_color(0.3, 1.0, 0.0, GW_xp_hud_brht+.2)
    graphics.draw_angle_arrow(SCREEN_WIDTH - window_x, SCREEN_HIGHT - window_y, GW_xp_WDir - GW_xp_ADir, 30, 0, 4)
    graphics.draw_angle_arrow(SCREEN_WIDTH - window_x, SCREEN_HIGHT - window_y, GW_xp_WDir - GW_xp_ADir - 180, 30, 18, 4)
    graphics.draw_outer_tracer(SCREEN_WIDTH - window_x, SCREEN_HIGHT - window_y, GW_xp_WSpd * 9, 30, 12)
    
    for i = 0 , 7, 1 do
      graphics.draw_tick_mark(SCREEN_WIDTH - window_x, SCREEN_HIGHT - window_y, i * 45, 40, 10, 1)
    end
    
    local string = ""
    if GW_xp_WSpd < 10 then
      string = " " .. string.format("% 2.1f", GW_xp_WSpd)
    else
      string = string.format("% 2.1f", GW_xp_WSpd)
      
    end
    draw_string_Helvetica_18(SCREEN_WIDTH - window_x - 22, SCREEN_HIGHT - window_y + 7, string)
    
    
  end
end
do_every_draw("GW_main()")
